# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools.

Nesse curso é ensinando como contribuir com projetos de código aberto.

Link para o curso [Python Pro](https://pythonpro.com.br/)

[![Build Status](https://travis-ci.com/tiagotardelli/libpythonpro.svg?branch=main)](https://travis-ci.com/tiagotardelli/libpythonpro)

![Build Status](https://github.com/tiagotardelli/libpythonpro/actions/workflows/libpythonpro.yml/badge.svg)

[![Updates](https://pyup.io/repos/github/tiagotardelli/libpythonpro/shield.svg)](https://pyup.io/repos/github/tiagotardelli/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/tiagotardelli/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/tiagotardelli/libpythonpro/)
Restructured Text
Suportada versão 3 de Python

Para instalar:
```console
python3 -m venv .venv
surce .venv/bin/activate
pip install -r /requirements-dev.txt

```

Para conferir qualidade de código:

```console
flake8

```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip